diff --git a/substrate/frame/message-queue/src/lib.rs b/substrate/frame/message-queue/src/lib.rs
index 6c264be3c834e4010a0516c4cd41fe02bb5501a7..409503d31725a4c63fb51ca5a5265859a451398c 100644
--- a/substrate/frame/message-queue/src/lib.rs
+++ b/substrate/frame/message-queue/src/lib.rs
@@ -56,7 +56,7 @@
 //! **Pagination**
 //!
 //! Queues are stored in a *paged* manner by splitting their messages into [`Page`]s. This results
-//! in a lot of complexity when implementing the pallet but is completely necessary to archive the
+//! in a lot of complexity when implementing the pallet but is completely necessary to achieve the
 //! second #[Design Goal](design-goals). The problem comes from the fact a message can *possibly* be
 //! quite large, lets say 64KiB. This then results in a *MEL* of at least 64KiB which results in a
 //! PoV of at least 64KiB. Now we have the assumption that most messages are much shorter than their
diff --git a/substrate/frame/salary/src/tests.rs b/substrate/frame/salary/src/tests.rs
index 8649291225bc363b9f1e3038aacdbba1e5aa5cb8..e54b9612b152caeef0a49f8001cbacbdbc67633e 100644
--- a/substrate/frame/salary/src/tests.rs
+++ b/substrate/frame/salary/src/tests.rs
@@ -52,7 +52,7 @@ frame_support::construct_runtime!(
 
 parameter_types! {
 	pub BlockWeights: frame_system::limits::BlockWeights =
-		frame_system::limits::BlockWeights::simple_max(Weight::from_ref_time(1_000_000));
+		frame_system::limits::BlockWeights::simple_max(Weight::from_parts(1_000_000, 0));
 }
 impl frame_system::Config for Test {
 	type BaseCallFilter = Everything;
diff --git a/substrate/frame/salary/src/weights.rs b/substrate/frame/salary/src/weights.rs
index f678d086dfcd9555bf3d95946221f4910d2dacaf..6b43c58b6038cc4416d0c94175758875b99feab1 100644
--- a/substrate/frame/salary/src/weights.rs
+++ b/substrate/frame/salary/src/weights.rs
@@ -18,27 +18,26 @@
 //! Autogenerated weights for pallet_salary
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-02-26, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-03-03, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `bm3`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! HOSTNAME: `bm2`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("dev"), DB CACHE: 1024
 
 // Executed Command:
-// target/production/substrate
+// ./target/production/substrate
 // benchmark
 // pallet
 // --steps=50
 // --repeat=20
 // --extrinsic=*
+// --pallet=pallet_salary
 // --execution=wasm
 // --wasm-execution=compiled
 // --heap-pages=4096
-// --json-file=/var/lib/gitlab-runner/builds/zyw4fam_/0/parity/mirrors/substrate/.git/.artifacts/bench.json
-// --pallet=pallet_salary
 // --chain=dev
-// --header=./HEADER-APACHE2
-// --output=./frame/salary/src/weights.rs
-// --template=./.maintain/frame-weight-template.hbs
+// --header=HEADER-APACHE2
+// --output=frame/salary/src/weights.rs
+// --template=.maintain/frame-weight-template.hbs
 
 #![cfg_attr(rustfmt, rustfmt_skip)]
 #![allow(unused_parens)]
@@ -65,11 +64,10 @@ impl<T: frame_system::Config> WeightInfo for SubstrateWeight<T> {
 	/// Proof: Salary Status (max_values: Some(1), max_size: Some(56), added: 551, mode: MaxEncodedLen)
 	fn init() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `1120`
-		//  Estimated: `551`
-		// Minimum execution time: 21_058 nanoseconds.
-		Weight::from_ref_time(21_381_000)
-			.saturating_add(Weight::from_proof_size(551))
+		//  Measured:  `4`
+		//  Estimated: `1541`
+		// Minimum execution time: 11_793_000 picoseconds.
+		Weight::from_parts(12_080_000, 1541)
 			.saturating_add(T::DbWeight::get().reads(1_u64))
 			.saturating_add(T::DbWeight::get().writes(1_u64))
 	}
@@ -77,11 +75,10 @@ impl<T: frame_system::Config> WeightInfo for SubstrateWeight<T> {
 	/// Proof: Salary Status (max_values: Some(1), max_size: Some(56), added: 551, mode: MaxEncodedLen)
 	fn bump() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `1234`
-		//  Estimated: `551`
-		// Minimum execution time: 22_272 nanoseconds.
-		Weight::from_ref_time(22_923_000)
-			.saturating_add(Weight::from_proof_size(551))
+		//  Measured:  `118`
+		//  Estimated: `1541`
+		// Minimum execution time: 12_799_000 picoseconds.
+		Weight::from_parts(13_343_000, 1541)
 			.saturating_add(T::DbWeight::get().reads(1_u64))
 			.saturating_add(T::DbWeight::get().writes(1_u64))
 	}
@@ -93,11 +90,10 @@ impl<T: frame_system::Config> WeightInfo for SubstrateWeight<T> {
 	/// Proof: Salary Claimant (max_values: None, max_size: Some(78), added: 2553, mode: MaxEncodedLen)
 	fn induct() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `1510`
-		//  Estimated: `5621`
-		// Minimum execution time: 32_223 nanoseconds.
-		Weight::from_ref_time(32_663_000)
-			.saturating_add(Weight::from_proof_size(5621))
+		//  Measured:  `394`
+		//  Estimated: `8591`
+		// Minimum execution time: 20_299_000 picoseconds.
+		Weight::from_parts(20_664_000, 8591)
 			.saturating_add(T::DbWeight::get().reads(3_u64))
 			.saturating_add(T::DbWeight::get().writes(1_u64))
 	}
@@ -109,11 +105,10 @@ impl<T: frame_system::Config> WeightInfo for SubstrateWeight<T> {
 	/// Proof: Salary Claimant (max_values: None, max_size: Some(78), added: 2553, mode: MaxEncodedLen)
 	fn register() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `1616`
-		//  Estimated: `5621`
-		// Minimum execution time: 38_279 nanoseconds.
-		Weight::from_ref_time(38_996_000)
-			.saturating_add(Weight::from_proof_size(5621))
+		//  Measured:  `461`
+		//  Estimated: `8591`
+		// Minimum execution time: 24_195_000 picoseconds.
+		Weight::from_parts(24_528_000, 8591)
 			.saturating_add(T::DbWeight::get().reads(3_u64))
 			.saturating_add(T::DbWeight::get().writes(2_u64))
 	}
@@ -125,11 +120,10 @@ impl<T: frame_system::Config> WeightInfo for SubstrateWeight<T> {
 	/// Proof: RankedCollective Members (max_values: None, max_size: Some(42), added: 2517, mode: MaxEncodedLen)
 	fn payout() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `2241`
-		//  Estimated: `5621`
-		// Minimum execution time: 68_868 nanoseconds.
-		Weight::from_ref_time(70_160_000)
-			.saturating_add(Weight::from_proof_size(5621))
+		//  Measured:  `461`
+		//  Estimated: `8591`
+		// Minimum execution time: 47_609_000 picoseconds.
+		Weight::from_parts(48_462_000, 8591)
 			.saturating_add(T::DbWeight::get().reads(3_u64))
 			.saturating_add(T::DbWeight::get().writes(2_u64))
 	}
@@ -143,11 +137,10 @@ impl<T: frame_system::Config> WeightInfo for SubstrateWeight<T> {
 	/// Proof: System Account (max_values: None, max_size: Some(128), added: 2603, mode: MaxEncodedLen)
 	fn payout_other() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `2189`
-		//  Estimated: `8224`
-		// Minimum execution time: 68_804 nanoseconds.
-		Weight::from_ref_time(69_223_000)
-			.saturating_add(Weight::from_proof_size(8224))
+		//  Measured:  `461`
+		//  Estimated: `12184`
+		// Minimum execution time: 48_513_000 picoseconds.
+		Weight::from_parts(49_053_000, 12184)
 			.saturating_add(T::DbWeight::get().reads(4_u64))
 			.saturating_add(T::DbWeight::get().writes(3_u64))
 	}
@@ -157,11 +150,10 @@ impl<T: frame_system::Config> WeightInfo for SubstrateWeight<T> {
 	/// Proof: Salary Claimant (max_values: None, max_size: Some(78), added: 2553, mode: MaxEncodedLen)
 	fn check_payment() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `880`
-		//  Estimated: `3104`
-		// Minimum execution time: 19_027 nanoseconds.
-		Weight::from_ref_time(19_360_000)
-			.saturating_add(Weight::from_proof_size(3104))
+		//  Measured:  `202`
+		//  Estimated: `5084`
+		// Minimum execution time: 12_663_000 picoseconds.
+		Weight::from_parts(12_858_000, 5084)
 			.saturating_add(T::DbWeight::get().reads(2_u64))
 			.saturating_add(T::DbWeight::get().writes(2_u64))
 	}
@@ -173,11 +165,10 @@ impl WeightInfo for () {
 	/// Proof: Salary Status (max_values: Some(1), max_size: Some(56), added: 551, mode: MaxEncodedLen)
 	fn init() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `1120`
-		//  Estimated: `551`
-		// Minimum execution time: 21_058 nanoseconds.
-		Weight::from_ref_time(21_381_000)
-			.saturating_add(Weight::from_proof_size(551))
+		//  Measured:  `4`
+		//  Estimated: `1541`
+		// Minimum execution time: 11_793_000 picoseconds.
+		Weight::from_parts(12_080_000, 1541)
 			.saturating_add(RocksDbWeight::get().reads(1_u64))
 			.saturating_add(RocksDbWeight::get().writes(1_u64))
 	}
@@ -185,11 +176,10 @@ impl WeightInfo for () {
 	/// Proof: Salary Status (max_values: Some(1), max_size: Some(56), added: 551, mode: MaxEncodedLen)
 	fn bump() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `1234`
-		//  Estimated: `551`
-		// Minimum execution time: 22_272 nanoseconds.
-		Weight::from_ref_time(22_923_000)
-			.saturating_add(Weight::from_proof_size(551))
+		//  Measured:  `118`
+		//  Estimated: `1541`
+		// Minimum execution time: 12_799_000 picoseconds.
+		Weight::from_parts(13_343_000, 1541)
 			.saturating_add(RocksDbWeight::get().reads(1_u64))
 			.saturating_add(RocksDbWeight::get().writes(1_u64))
 	}
@@ -201,11 +191,10 @@ impl WeightInfo for () {
 	/// Proof: Salary Claimant (max_values: None, max_size: Some(78), added: 2553, mode: MaxEncodedLen)
 	fn induct() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `1510`
-		//  Estimated: `5621`
-		// Minimum execution time: 32_223 nanoseconds.
-		Weight::from_ref_time(32_663_000)
-			.saturating_add(Weight::from_proof_size(5621))
+		//  Measured:  `394`
+		//  Estimated: `8591`
+		// Minimum execution time: 20_299_000 picoseconds.
+		Weight::from_parts(20_664_000, 8591)
 			.saturating_add(RocksDbWeight::get().reads(3_u64))
 			.saturating_add(RocksDbWeight::get().writes(1_u64))
 	}
@@ -217,11 +206,10 @@ impl WeightInfo for () {
 	/// Proof: Salary Claimant (max_values: None, max_size: Some(78), added: 2553, mode: MaxEncodedLen)
 	fn register() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `1616`
-		//  Estimated: `5621`
-		// Minimum execution time: 38_279 nanoseconds.
-		Weight::from_ref_time(38_996_000)
-			.saturating_add(Weight::from_proof_size(5621))
+		//  Measured:  `461`
+		//  Estimated: `8591`
+		// Minimum execution time: 24_195_000 picoseconds.
+		Weight::from_parts(24_528_000, 8591)
 			.saturating_add(RocksDbWeight::get().reads(3_u64))
 			.saturating_add(RocksDbWeight::get().writes(2_u64))
 	}
@@ -233,11 +221,10 @@ impl WeightInfo for () {
 	/// Proof: RankedCollective Members (max_values: None, max_size: Some(42), added: 2517, mode: MaxEncodedLen)
 	fn payout() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `2241`
-		//  Estimated: `5621`
-		// Minimum execution time: 68_868 nanoseconds.
-		Weight::from_ref_time(70_160_000)
-			.saturating_add(Weight::from_proof_size(5621))
+		//  Measured:  `461`
+		//  Estimated: `8591`
+		// Minimum execution time: 47_609_000 picoseconds.
+		Weight::from_parts(48_462_000, 8591)
 			.saturating_add(RocksDbWeight::get().reads(3_u64))
 			.saturating_add(RocksDbWeight::get().writes(2_u64))
 	}
@@ -251,11 +238,10 @@ impl WeightInfo for () {
 	/// Proof: System Account (max_values: None, max_size: Some(128), added: 2603, mode: MaxEncodedLen)
 	fn payout_other() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `2189`
-		//  Estimated: `8224`
-		// Minimum execution time: 68_804 nanoseconds.
-		Weight::from_ref_time(69_223_000)
-			.saturating_add(Weight::from_proof_size(8224))
+		//  Measured:  `461`
+		//  Estimated: `12184`
+		// Minimum execution time: 48_513_000 picoseconds.
+		Weight::from_parts(49_053_000, 12184)
 			.saturating_add(RocksDbWeight::get().reads(4_u64))
 			.saturating_add(RocksDbWeight::get().writes(3_u64))
 	}
@@ -265,11 +251,10 @@ impl WeightInfo for () {
 	/// Proof: Salary Claimant (max_values: None, max_size: Some(78), added: 2553, mode: MaxEncodedLen)
 	fn check_payment() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `880`
-		//  Estimated: `3104`
-		// Minimum execution time: 19_027 nanoseconds.
-		Weight::from_ref_time(19_360_000)
-			.saturating_add(Weight::from_proof_size(3104))
+		//  Measured:  `202`
+		//  Estimated: `5084`
+		// Minimum execution time: 12_663_000 picoseconds.
+		Weight::from_parts(12_858_000, 5084)
 			.saturating_add(RocksDbWeight::get().reads(2_u64))
 			.saturating_add(RocksDbWeight::get().writes(2_u64))
 	}